# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`db2_profile`](#db2_profile): Common variables
* [`db2_profile::database`](#db2_profiledatabase): This is a highly customizable Puppet profile class to define an IBM DB2 database on your system.
* [`db2_profile::database::cis_controls`](#db2_profiledatabasecis_controls): This class contains the actual code securing the database.
* [`db2_profile::database::db_definition`](#db2_profiledatabasedb_definition): This class contains the actual database definition using the `db2_database` type.
* [`db2_profile::database::db_fixpack`](#db2_profiledatabasedb_fixpack): This class ensure's that the correct DB2 fixpack is installed.
* [`db2_profile::database::db_fixpack_multiple`](#db2_profiledatabasedb_fixpack_multiple): This class ensure's that the correct DB2 fixpack is installed.
* [`db2_profile::database::db_groups`](#db2_profiledatabasedb_groups): This class contains the definition for all the database users you'd like on your system.
* [`db2_profile::database::db_instance`](#db2_profiledatabasedb_instance): This class allows you to specify what DB2 database instance you want to define on your databases.
* [`db2_profile::database::db_primary`](#db2_profiledatabasedb_primary): When the property `db2_profile::database::primary` is set, and the current node is the designated primary server, this class will be applied.
* [`db2_profile::database::db_roles`](#db2_profiledatabasedb_roles): This class allows you to specify what DB2 database role you want to define on your databases.
* [`db2_profile::database::db_schemas`](#db2_profiledatabasedb_schemas): This class contains the definition for all the database users you'd like on your system.
* [`db2_profile::database::db_software`](#db2_profiledatabasedb_software): This class installs the IBM DB2 sofware on your system.
* [`db2_profile::database::db_software_multiple`](#db2_profiledatabasedb_software_multiple): This class allows you in install mutiple instances of DB2 sofware on your system.
* [`db2_profile::database::db_standby`](#db2_profiledatabasedb_standby): When the property `db2_profile::database::primary` is set, and the current node is not the designated primary server, this class will be applied.
* [`db2_profile::database::db_startup`](#db2_profiledatabasedb_startup): This class ensures that the specified instance will be started after a system reboot.
* [`db2_profile::database::db_tablespaces`](#db2_profiledatabasedb_tablespaces): This class allows you to specify what DB2 database tablespace you want to define on your databases.
* [`db2_profile::database::db_users`](#db2_profiledatabasedb_users): This class allows you to specify what DB2 database user you want to define on your databases.
* [`db2_profile::database::em_license`](#db2_profiledatabaseem_license): db2_profile::database::em_license  See the file "LICENSE" for the full license governing this code.
* [`db2_profile::database::fact_caching`](#db2_profiledatabasefact_caching): This class will enable DB2 fact caching, when enabled.
* [`db2_profile::database::pacemaker_setup`](#db2_profiledatabasepacemaker_setup): This class takes care of applying all Pacemeker resources.
* [`db2_profile::database::passwordless_root`](#db2_profiledatabasepasswordless_root): The class enables passwordless root access between the nodes in the cluster.
* [`db2_profile::secured_database`](#db2_profilesecured_database): db2_profile::secured_database  See the file "LICENSE" for the full license governing this code.

### Data types

* [`Db2_profile::Sw_def`](#db2_profilesw_def)

## Classes

### <a name="db2_profile"></a>`db2_profile`

db2_profile::db2_profile

See the file "LICENSE" for the full license governing this code.

#### Parameters

The following parameters are available in the `db2_profile` class:

* [`location`](#location)
* [`source`](#source)
* [`version`](#version)

##### <a name="location"></a>`location`

Data type: `String[1]`

The locatin where the DB2 sofware is or will be installed.

##### <a name="source"></a>`source`

Data type: `Stdlib::Absolutepath`

The location of the DB2 software.
Here is an example on how to use this:
    class { '::db2_install::...':
      ...
      source => '/software',
      ...
    }

##### <a name="version"></a>`version`

Data type: `Db2_Install::Version`

The version to be installed.
Here is an example on how to use this:
    class { '::db2_install::software':
      ...
      version => '11.0.0.0',
      ...
    }

### <a name="db2_profiledatabase"></a>`db2_profile::database`

db2_profile::database

In it's core just adding:

```
contain db2_profile::database
```

Is enough to get an IBM DB2 database running on your system.

But sometimes you have specific uses cases that are not handled well by the standard classes. This profile class allows you to add your own code to the execution.

## Steps

Defining and starting an DB2 database on you system goes through several steps :

- `em_license`        (setup Enterprise Modules licenses)
- `fact_caching`      (Configure DB2 fact caching)
- `sysctl`            (Set required sysctl settings)
- `limits`            (Set required security limits)
- `groups_and_users`  (Ensure required OS groups and users)
- `packages`          (Ensure require OS packages)
- `firewall`          (Configure firewall for DB2 usage)
- `db_software`       (Install the DB2 software)
- `db_fixpack`        (Install the DB2 fixpack)
- `db_instance`       (Ensure DB2 instances)
- `db_definition`     (Ensure DB2 databases)
- `db_primary`        (Set the database as primary database when using HADR)
- `db_standby`        (Set the database as standby database when using HADR)
- `db_tablespaces`    (Ensure DB2 tablespaces)
- `db_users`          (Ensure DB2 users in database)
- `db_roles`          (Ensure DB2 roles)
- `db_groups`         (Ensure DB2 groups in database)
- `db_schemas`        (Ensure DB2 schemas)
- `db_startup`        (Esnure DB2 startup after reboot)


All these steps have a default implementation. This implementation is suitable to get started with. These classed all have parameters you can customize through hiera values. The defaults are specified in the module's `data/default.yaml` file.

## before classes

But sometimes this is not enough and you would like to add some extra definitions, you can, for example, add a Puppet class to be executed after the `systctl` stage is done and before the `limits` is done. You can do this by adding the next line to your yaml data:

```yaml
db2_profile::database::before_sysctl:   my_profile::my_extra_class
```

## after classes

You can do the same when you want to add code after one of the stage classes:

```yaml
db2_profile::database::after_sysctl:   my_profile::my_extra_class
```

## Skipping

Sometimes organisation use different modules and mechanisms to implement a feature and you want to skip the class:

```yaml
db2_profile::database::sysctl:   skip
```

## Replacing

Or provide your own implementation:

```yaml
db2_profile::database::sysctl:   my_profile::my_own_implementation
```

This mechanism can be used for all named steps and makes it easy to move from an easy setup with a running standard database to a fully customized setup using a lot of your own classes plugged in.

Look at the description of the steps and their properties.

See the file "LICENSE" for the full license governing this code.

#### Parameters

The following parameters are available in the `db2_profile::database` class:

* [`cluster_manager`](#cluster_manager)
* [`passwordless_root`](#passwordless_root)
* [`before_passwordless_root`](#before_passwordless_root)
* [`after_passwordless_root`](#after_passwordless_root)
* [`pacemaker_setup`](#pacemaker_setup)
* [`before_pacemaker_setup`](#before_pacemaker_setup)
* [`after_pacemaker_setup`](#after_pacemaker_setup)
* [`after_db_primary`](#after_db_primary)
* [`after_db_standby`](#after_db_standby)
* [`before_db_primary`](#before_db_primary)
* [`before_db_standby`](#before_db_standby)
* [`db_primary`](#db_primary)
* [`db_standby`](#db_standby)
* [`primary`](#primary)
* [`after_db_definition`](#after_db_definition)
* [`after_db_fixpack`](#after_db_fixpack)
* [`after_db_instance`](#after_db_instance)
* [`after_db_roles`](#after_db_roles)
* [`after_db_software`](#after_db_software)
* [`after_db_startup`](#after_db_startup)
* [`after_db_tablespaces`](#after_db_tablespaces)
* [`after_db_users`](#after_db_users)
* [`after_db_groups`](#after_db_groups)
* [`after_db_schemas`](#after_db_schemas)
* [`after_em_license`](#after_em_license)
* [`after_fact_caching`](#after_fact_caching)
* [`after_firewall`](#after_firewall)
* [`after_groups_and_users`](#after_groups_and_users)
* [`after_limits`](#after_limits)
* [`after_packages`](#after_packages)
* [`after_sysctl`](#after_sysctl)
* [`before_db_definition`](#before_db_definition)
* [`before_db_fixpack`](#before_db_fixpack)
* [`before_db_instance`](#before_db_instance)
* [`before_db_roles`](#before_db_roles)
* [`before_db_software`](#before_db_software)
* [`before_db_startup`](#before_db_startup)
* [`before_db_schemas`](#before_db_schemas)
* [`before_db_tablespaces`](#before_db_tablespaces)
* [`before_db_users`](#before_db_users)
* [`before_db_groups`](#before_db_groups)
* [`before_em_license`](#before_em_license)
* [`before_fact_caching`](#before_fact_caching)
* [`before_firewall`](#before_firewall)
* [`before_groups_and_users`](#before_groups_and_users)
* [`before_limits`](#before_limits)
* [`before_packages`](#before_packages)
* [`before_sysctl`](#before_sysctl)
* [`db_definition`](#db_definition)
* [`db_fixpack`](#db_fixpack)
* [`db_instance`](#db_instance)
* [`db_roles`](#db_roles)
* [`db_groups`](#db_groups)
* [`db_schemas`](#db_schemas)
* [`db_software`](#db_software)
* [`db_startup`](#db_startup)
* [`db_tablespaces`](#db_tablespaces)
* [`db_users`](#db_users)
* [`em_license`](#em_license)
* [`fact_caching`](#fact_caching)
* [`firewall`](#firewall)
* [`groups_and_users`](#groups_and_users)
* [`limits`](#limits)
* [`packages`](#packages)
* [`sysctl`](#sysctl)

##### <a name="cluster_manager"></a>`cluster_manager`

Data type: `Optional[String]`

The cluster manager to apply when using a HADR setup.
At this point in time only the Pacemaker cluster manager is supported.
When you leave this paramater undefined, no cluster manager is applied.

Default value: ``undef``

##### <a name="passwordless_root"></a>`passwordless_root`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `limits`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::passwordless_root:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::passwordless_root:  skip
```

Default value: ``undef``

##### <a name="before_passwordless_root"></a>`before_passwordless_root`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `passwordless_root` class.
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::before_passwordless_root:  my_module::my_class
```

Default value: ``undef``

##### <a name="after_passwordless_root"></a>`after_passwordless_root`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `passwordless_root` class.
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::after_passwordless_root:  my_module::my_class
```

Default value: ``undef``

##### <a name="pacemaker_setup"></a>`pacemaker_setup`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `pacemaker_setup`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::pacemaker_setup:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::pacemaker_setup:  skip
```

Default value: ``undef``

##### <a name="before_pacemaker_setup"></a>`before_pacemaker_setup`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `pacemaker_setup` class.
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::before_pacemaker_setup:  my_module::my_class
```

Default value: ``undef``

##### <a name="after_pacemaker_setup"></a>`after_pacemaker_setup`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `pacemaker_setup` class.
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::after_pacemaker_setup:  my_module::my_class
```

Default value: ``undef``

##### <a name="after_db_primary"></a>`after_db_primary`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `db_primary` class.
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::after_db_primary:  my_module::my_class
```

Default value: ``undef``

##### <a name="after_db_standby"></a>`after_db_standby`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `db_standby` class.
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::after_db_primary:  my_module::my_class
```

Default value: ``undef``

##### <a name="before_db_primary"></a>`before_db_primary`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `db_primary` class.
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::before_db_primary:  my_module::my_class
```

Default value: ``undef``

##### <a name="before_db_standby"></a>`before_db_standby`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `db_standby` class.
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::before_db_standby:  my_module::my_class
```

Default value: ``undef``

##### <a name="db_primary"></a>`db_primary`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `db_primary`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::db_primary:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::db_primary:  skip
```

Default value: ``undef``

##### <a name="db_standby"></a>`db_standby`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `db_standby`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::db_standby:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::db_standby:  skip
```

Default value: ``undef``

##### <a name="primary"></a>`primary`

Data type: `Optional[String[1]]`

The full qualified host name of the node you wan to use as primary DB2 node.
When you specify this variable, Puppet will create a HADR DB2 configuration. When the current FQDN equals the name specfied here, Puppet will create a primary DB2 node. When the FQDN is different, Puppet will configure the node as a standby database.
You'll have to ensure the the setting for the `db2_database` for all nodes are set correctly. These values are relevant:
- hadr_local_host
- hadr_local_svc
- hadr_remote_host
- hadr_remote_svc
- hadr_remote_inst

Default value: ``undef``

##### <a name="after_db_definition"></a>`after_db_definition`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `db_definition` class.
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::after_db_definition:  my_module::my_class
```

Default value: ``undef``

##### <a name="after_db_fixpack"></a>`after_db_fixpack`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `db_fixpack` class.
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::after_db_fixpack:  my_module::my_class
```

Default value: ``undef``

##### <a name="after_db_instance"></a>`after_db_instance`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `db_instance` class.
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::after_db_instance:  my_module::my_class
```

Default value: ``undef``

##### <a name="after_db_roles"></a>`after_db_roles`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `db_roles` class.
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::after_db_roles:  my_module::my_class
```

Default value: ``undef``

##### <a name="after_db_software"></a>`after_db_software`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `db_software` class.
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::after_db_software:  my_module::my_class
```

Default value: ``undef``

##### <a name="after_db_startup"></a>`after_db_startup`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `db_startup` class.
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::after_db_startup:  my_module::my_class
```

Default value: ``undef``

##### <a name="after_db_tablespaces"></a>`after_db_tablespaces`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `db_tablespaces` class.
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::after_db_tablespaces:  my_module::my_class
```

Default value: ``undef``

##### <a name="after_db_users"></a>`after_db_users`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `db_users` class.
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::after_db_users:  my_module::my_class
```

Default value: ``undef``

##### <a name="after_db_groups"></a>`after_db_groups`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `db_groups` class.
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::after_db_groups:  my_module::my_class
```

Default value: ``undef``

##### <a name="after_db_schemas"></a>`after_db_schemas`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `db_schemas` class.
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::after_db_schemas:  my_module::my_class
```

Default value: ``undef``

##### <a name="after_em_license"></a>`after_em_license`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `em_license` class.
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::after_em_license:  my_module::my_class
```

Default value: ``undef``

##### <a name="after_fact_caching"></a>`after_fact_caching`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `fact_caching` class.
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::after_fact_caching:  my_module::my_class
```

Default value: ``undef``

##### <a name="after_firewall"></a>`after_firewall`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `firewall` class.
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::after_firewall:  my_module::my_class
```

Default value: ``undef``

##### <a name="after_groups_and_users"></a>`after_groups_and_users`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `groups_and_users` class.
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::after_groups_and_users:  my_module::my_class
```

Default value: ``undef``

##### <a name="after_limits"></a>`after_limits`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `limits` class.
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::after_limits:  my_module::my_class
```

Default value: ``undef``

##### <a name="after_packages"></a>`after_packages`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `packages` class.
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::after_packages:  my_module::my_class
```

Default value: ``undef``

##### <a name="after_sysctl"></a>`after_sysctl`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `sysctl` class.
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::after_sysctl:  my_module::my_class
```

Default value: ``undef``

##### <a name="before_db_definition"></a>`before_db_definition`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `db_definitio` class.
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::before_db_definitio:  my_module::my_class
```

Default value: ``undef``

##### <a name="before_db_fixpack"></a>`before_db_fixpack`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `db_fixpack` class.
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::before_db_fixpack:  my_module::my_class
```

Default value: ``undef``

##### <a name="before_db_instance"></a>`before_db_instance`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `db_instance` class.
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::before_db_instance:  my_module::my_class
```

Default value: ``undef``

##### <a name="before_db_roles"></a>`before_db_roles`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `db_roles` class.
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::before_db_roles:  my_module::my_class
```

Default value: ``undef``

##### <a name="before_db_software"></a>`before_db_software`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `db_software` class.
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::before_db_software:  my_module::my_class
```

Default value: ``undef``

##### <a name="before_db_startup"></a>`before_db_startup`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `db_startup` class.
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::before_db_startup:  my_module::my_class
```

Default value: ``undef``

##### <a name="before_db_schemas"></a>`before_db_schemas`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `db_schemas` class.
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::before_db_schemas:  my_module::my_class
```

Default value: ``undef``

##### <a name="before_db_tablespaces"></a>`before_db_tablespaces`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `db_tablespaces` class.
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::before_db_tablespaces:  my_module::my_class
```

Default value: ``undef``

##### <a name="before_db_users"></a>`before_db_users`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `db_users` class.
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::before_db_users:  my_module::my_class
```

Default value: ``undef``

##### <a name="before_db_groups"></a>`before_db_groups`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `db_groups` class.
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::before_db_groups:  my_module::my_class
```

Default value: ``undef``

##### <a name="before_em_license"></a>`before_em_license`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `em_license` class.
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::before_em_license:  my_module::my_class
```

Default value: ``undef``

##### <a name="before_fact_caching"></a>`before_fact_caching`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `fact_caching` class.
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::before_fact_caching:  my_module::my_class
```

Default value: ``undef``

##### <a name="before_firewall"></a>`before_firewall`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `firewall` class.
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::before_firewall:  my_module::my_class
```

Default value: ``undef``

##### <a name="before_groups_and_users"></a>`before_groups_and_users`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `groups_and_users` class.
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::before_groups_and_users:  my_module::my_class
```

Default value: ``undef``

##### <a name="before_limits"></a>`before_limits`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `limits` class.
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::before_limits:  my_module::my_class
```

Default value: ``undef``

##### <a name="before_packages"></a>`before_packages`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `packages` class.
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::before_packages:  my_module::my_class
```

Default value: ``undef``

##### <a name="before_sysctl"></a>`before_sysctl`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `sysctl` class.
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::before_sysctl:  my_module::my_class
```

Default value: ``undef``

##### <a name="db_definition"></a>`db_definition`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `db_definition`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::db_definition:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::db_definition:  skip
```

Default value: ``undef``

##### <a name="db_fixpack"></a>`db_fixpack`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `db_fixpack`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::db_fixpack:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::db_fixpack:  skip
```

Default value: ``undef``

##### <a name="db_instance"></a>`db_instance`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `db_instance`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::db_instance:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::db_instance:  skip
```

Default value: ``undef``

##### <a name="db_roles"></a>`db_roles`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `db_roles`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::db_roles:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::db_roles:  skip
```

Default value: ``undef``

##### <a name="db_groups"></a>`db_groups`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `db_groups`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::db_groups:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::db_groups:  skip
```

Default value: ``undef``

##### <a name="db_schemas"></a>`db_schemas`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `db_schemas`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::db_schemas:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::db_schemas:  skip
```

Default value: ``undef``

##### <a name="db_software"></a>`db_software`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `db_software`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::db_software:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::db_software:  skip
```

Default value: ``undef``

##### <a name="db_startup"></a>`db_startup`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `db_startup`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::db_startup:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::db_startup:  skip
```

Default value: ``undef``

##### <a name="db_tablespaces"></a>`db_tablespaces`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `db_tablespaces`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::db_tablespaces:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::db_tablespaces:  skip
```

Default value: ``undef``

##### <a name="db_users"></a>`db_users`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `db_users`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::db_users:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::db_users:  skip
```

Default value: ``undef``

##### <a name="em_license"></a>`em_license`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `em_license`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::em_license:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::em_license:  skip
```

Default value: ``undef``

##### <a name="fact_caching"></a>`fact_caching`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `fact_caching`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::fact_caching:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::fact_caching:  skip
```

Default value: ``undef``

##### <a name="firewall"></a>`firewall`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `firewall`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::firewall:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::firewall:  skip
```

Default value: ``undef``

##### <a name="groups_and_users"></a>`groups_and_users`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `groups_and_users`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::groups_and_users:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::groups_and_users:  skip
```

Default value: ``undef``

##### <a name="limits"></a>`limits`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `limits`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::limits:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::limits:  skip
```

Default value: ``undef``

##### <a name="packages"></a>`packages`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `packages`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::packages:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::packages:  skip
```

Default value: ``undef``

##### <a name="sysctl"></a>`sysctl`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for stage `sysctl`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::sysctl:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
db2_profile::database::sysctl:  skip
```

Default value: ``undef``

### <a name="db2_profiledatabasecis_controls"></a>`db2_profile::database::cis_controls`

db2_profile::database::cis_controls

Here you can customize the security by specifying the CIS rules you *don't* want to apply.


When these customizations aren't enough, you can replace the class with your own class. See [db2_profile::secured_database](./secured_database.html) for an explanation on how to do this.

See the file "LICENSE" for the full license governing this code.

#### Parameters

The following parameters are available in the `db2_profile::database::cis_controls` class:

* [`instance`](#instance)
* [`database`](#database)
* [`product_version`](#product_version)
* [`doc_version`](#doc_version)
* [`skip_list`](#skip_list)

##### <a name="instance"></a>`instance`

Data type: `String[1]`

The instance to use for the database.

##### <a name="database"></a>`database`

Data type: `String[1]`

The database name to use for the primary or standby database.
this needs to be the same on the primary and standby nodes.

##### <a name="product_version"></a>`product_version`

Data type: `Optional[String[1]]`

The database version of the CIS benchmark you want to apply.
Although not very logical, you **can** apply an older (or newer) database version to your database.
If you also don't specify a `product_version`, Puppet will detect the version of Postgres running and use this to determine the `product_version`. There is, however, one issue with the detection. On an initial run Puppet canot determine what the Postgres version is. In that case, the ora_cis defined type will skip applying the CIS benchmark and wait until (hopefully) the next run the version of Postgres for specified sid is available.

##### <a name="doc_version"></a>`doc_version`

Data type: `Optional[String[1]]`

The version of the CIS benchmark you want to apply to your database.
When you don't specify the `doc_version`, puppet automatically uses the latest version for your current `db_version`.

##### <a name="skip_list"></a>`skip_list`

Data type: `Optional[Array[String[1]]]`

This is the list of controls that you want to skip.
By default this value is empty, meaning `ora_cis` will apply **ALL** controls. You must specify the name of the control.

### <a name="db2_profiledatabasedb_definition"></a>`db2_profile::database::db_definition`

db2_profile::database::db_definition

Here you can customize some of the attributes of your database.

When these customizations aren't enough, you can replace the class with your own class. See [db2_config::db2_database](/docs/db2_config/db2_database.html) for an explanation on how to do this.

See the file "LICENSE" for the full license governing this code.

#### Parameters

The following parameters are available in the `db2_profile::database::db_definition` class:

* [`list`](#list)

##### <a name="list"></a>`list`

Data type: `Hash`

The list of [db2_database](/docs/db2_config/db2_database.
html) database you want `db2_profile::database` to create and manage for you.

### <a name="db2_profiledatabasedb_fixpack"></a>`db2_profile::database::db_fixpack`

db2_profile::database::db_fixpack

See the file "LICENSE" for the full license governing this code.

#### Parameters

The following parameters are available in the `db2_profile::database::db_fixpack` class:

* [`temp_dir`](#temp_dir)
* [`version`](#version)
* [`source`](#source)
* [`file_name`](#file_name)
* [`location`](#location)
* [`logoutput`](#logoutput)

##### <a name="temp_dir"></a>`temp_dir`

Data type: `Stdlib::Absolutepath`

This defined type uses a temporary directory.
By default this is `\tmp`. If you want to use an other directory for this, you must specify this parameter.
Here is an example on how to use this:
    class { '::db2_install::...':
      ...
      temp_dir => '/my_tmp_dir',
      ...
    }
On systems with a secured `/tmp` direcory, you MUST specify the `tmp_dir` parameter and specify a directory that puppet is allowed to execute scripts from. It must also have enough space to receive the extracted MQ installation kit.

Default value: `'/tmp'`

##### <a name="version"></a>`version`

Data type: `Optional[String[1]]`

The version to be installed.
Here is an example on how to use this:
    class { '::db2_install::software':
      ...
      version => '11.0.0.0',
      ...
    }

Default value: ``undef``

##### <a name="source"></a>`source`

Data type: `String[1]`

The location of the DB2 software.
Here is an example on how to use this:
    class { '::db2_install::...':
      ...
      source => '/software',
      ...
    }

##### <a name="file_name"></a>`file_name`

Data type: `Optional[String[1]]`

The file containing the install kit for the DB2 software.

Default value: ``undef``

##### <a name="location"></a>`location`

Data type: `Stdlib::Absolutepath`

The locatin where the DB2 sofware is or will be installed.

##### <a name="logoutput"></a>`logoutput`

Data type: `Variant[Boolean,Enum['on_failure']]`

If you want to see the output of the `exec` resources in the type, you can set this value to `true`.
The default is `on_failure`.
Here is an example on how to use this:
    class { '::db2_install::...':
      ...
      logoutput => true,
      ...
    }

Default value: `lookup({ name => 'logoutput', default_value => 'on_failure' })`

### <a name="db2_profiledatabasedb_fixpack_multiple"></a>`db2_profile::database::db_fixpack_multiple`

db2_profile::database::db_fixpack_multiple

See the file "LICENSE" for the full license governing this code.

#### Parameters

The following parameters are available in the `db2_profile::database::db_fixpack_multiple` class:

* [`software`](#software)
* [`source`](#source)
* [`logoutput`](#logoutput)
* [`temp_dir`](#temp_dir)

##### <a name="software"></a>`software`

Data type: `Hash[String[1], Db2_profile::Sw_def]`

A Hash containing the locations you want the software of a  fixpeck to be applied to.

##### <a name="source"></a>`source`

Data type: `String[1]`

The location of the DB2 software.
Here is an example on how to use this:
    class { '::db2_install::...':
      ...
      source => '/software',
      ...
    }

##### <a name="logoutput"></a>`logoutput`

Data type: `Variant[Boolean,Enum['on_failure']]`

If you want to see the output of the `exec` resources in the type, you can set this value to `true`.
The default is `on_failure`.
Here is an example on how to use this:
    class { '::db2_install::...':
      ...
      logoutput => true,
      ...
    }

Default value: `lookup({ name => 'logoutput', default_value => 'on_failure' })`

##### <a name="temp_dir"></a>`temp_dir`

Data type: `Stdlib::Absolutepath`

This defined type uses a temporary directory.
By default this is `\tmp`. If you want to use an other directory for this, you must specify this parameter.
Here is an example on how to use this:
    class { '::db2_install::...':
      ...
      temp_dir => '/my_tmp_dir',
      ...
    }
On systems with a secured `/tmp` direcory, you MUST specify the `tmp_dir` parameter and specify a directory that puppet is allowed to execute scripts from. It must also have enough space to receive the extracted MQ installation kit.

Default value: `'/tmp'`

### <a name="db2_profiledatabasedb_groups"></a>`db2_profile::database::db_groups`

db2_profile::database::db_users

When these customizations aren't enough, you can replace the class with your own class. See [db2_profile::database](./database.html) for an explanation on how to do this.

See the file "LICENSE" for the full license governing this code.

#### Parameters

The following parameters are available in the `db2_profile::database::db_groups` class:

* [`list`](#list)

##### <a name="list"></a>`list`

Data type: `Hash`

A list of database users to define.
You must specify a Hash of [db2_user](/docs/db2_config/db2_user.html)
The default value is: `{}`
This is a simple way to get started. It is easy to get started, but soon your hiera yaml become a nigtmare. Our advise is when you need to let puppet manage your DB2 group, to override this class and  add your own puppet implementation. This is much better maintainable
and adds more consistency.

### <a name="db2_profiledatabasedb_instance"></a>`db2_profile::database::db_instance`

db2_profile::database::db_instance

Check the documentation of [db2_instance](/docs/db2_config/db2_instance.html) on how to do this and what properties you can define on an instance.

See the file "LICENSE" for the full license governing this code.

#### Parameters

The following parameters are available in the `db2_profile::database::db_instance` class:

* [`list`](#list)

##### <a name="list"></a>`list`

Data type: `Hash`

The list of [db2_instance](/docs/db2_config/db2_instance.
html) instances you want `db2_profile::database` to create and manage for you.

### <a name="db2_profiledatabasedb_primary"></a>`db2_profile::database::db_primary`

db2_profile::database::db_primary

It will set the database in archiving mode, create a backup and then set the database in primary mode.

See the file "LICENSE" for the full license governing this code.

#### Parameters

The following parameters are available in the `db2_profile::database::db_primary` class:

* [`instance`](#instance)
* [`database`](#database)
* [`archive_path`](#archive_path)
* [`backup_path`](#backup_path)
* [`owner`](#owner)
* [`group`](#group)
* [`wait_time`](#wait_time)
* [`logoutput`](#logoutput)

##### <a name="instance"></a>`instance`

Data type: `String[1]`

The instance to use for the database.

##### <a name="database"></a>`database`

Data type: `String[1]`

The database name to use for the primary or standby database.
this needs to be the same on the primary and standby nodes.

##### <a name="archive_path"></a>`archive_path`

Data type: `Stdlib::Absolutepath`

The path to use for DB2 archiving.

##### <a name="backup_path"></a>`backup_path`

Data type: `Stdlib::Absolutepath`

The location to put the DB2 database backup.

##### <a name="owner"></a>`owner`

Data type: `String[1]`

The owner to use for the archive and backup directories.

##### <a name="group"></a>`group`

Data type: `String[1]`

The group to use for the archive and backup directories.

##### <a name="wait_time"></a>`wait_time`

Data type: `Integer`

The in seconds to wait to set he database in primary mode aftercthe backup has been made.

##### <a name="logoutput"></a>`logoutput`

Data type: `Variant[Boolean,Enum['on_failure']]`

If you want to see the output of the `exec` resources in the type, you can set this value to `true`.
The default is `on_failure`.
Here is an example on how to use this:
    class { '::db2_install::...':
      ...
      logoutput => true,
      ...
    }

Default value: `lookup({ name => 'logoutput', default_value => 'on_failure' })`

### <a name="db2_profiledatabasedb_roles"></a>`db2_profile::database::db_roles`

db2_profile::database::db_roles

Check the documentation of [db2_role](/docs/db2_config/db2_role) on how to do this and what properties you can define on an role.

See the file "LICENSE" for the full license governing this code.

#### Parameters

The following parameters are available in the `db2_profile::database::db_roles` class:

* [`list`](#list)

##### <a name="list"></a>`list`

Data type: `Hash`

The list of [db2_role](/docs/db2_config/db2_role.
html) roles you want `db2_profile::database` to create and manage for you.

### <a name="db2_profiledatabasedb_schemas"></a>`db2_profile::database::db_schemas`

db2_profile::database::db_users

When these customizations aren't enough, you can replace the class with your own class. See [db2_profile::database](./database.html) for an explanation on how to do this.

See the file "LICENSE" for the full license governing this code.

#### Parameters

The following parameters are available in the `db2_profile::database::db_schemas` class:

* [`list`](#list)

##### <a name="list"></a>`list`

Data type: `Hash`

A list of database users to define.
You must specify a Hash of [db2_user](/docs/db2_config/db2_user.html)
The default value is: `{}`
This is a simple way to get started. It is easy to get started, but soon your hiera yaml become a nigtmare. Our advise is when you need to let puppet manage your DB2 schemas, to override this class and  add your own puppet implementation. This is much better maintainable
and adds more consistency.

### <a name="db2_profiledatabasedb_software"></a>`db2_profile::database::db_software`

db2_profile::database::db_software

See the file "LICENSE" for the full license governing this code.

#### Parameters

The following parameters are available in the `db2_profile::database::db_software` class:

* [`file_name`](#file_name)
* [`location`](#location)
* [`source`](#source)
* [`version`](#version)

##### <a name="file_name"></a>`file_name`

Data type: `String[1]`

The file containing the install kit for the DB2 software.

##### <a name="location"></a>`location`

Data type: `Stdlib::Absolutepath`

The locatin where the DB2 sofware is or will be installed.

##### <a name="source"></a>`source`

Data type: `String[1]`

The location of the DB2 software.
Here is an example on how to use this:
    class { '::db2_install::...':
      ...
      source => '/software',
      ...
    }

##### <a name="version"></a>`version`

Data type: `Db2_Install::Version`

The version to be installed.
Here is an example on how to use this:
    class { '::db2_install::software':
      ...
      version => '11.0.0.0',
      ...
    }

### <a name="db2_profiledatabasedb_software_multiple"></a>`db2_profile::database::db_software_multiple`

db2_profile::database::db_software_multiple

See the file "LICENSE" for the full license governing this code.

#### Parameters

The following parameters are available in the `db2_profile::database::db_software_multiple` class:

* [`software`](#software)
* [`source`](#source)

##### <a name="software"></a>`software`

Data type: `Hash[String[1], Db2_profile::Sw_def]`

A Hash containing the locations you want the software of a  fixpeck to be applied to.

##### <a name="source"></a>`source`

Data type: `String[1]`

The location of the DB2 software.
Here is an example on how to use this:
    class { '::db2_install::...':
      ...
      source => '/software',
      ...
    }

### <a name="db2_profiledatabasedb_standby"></a>`db2_profile::database::db_standby`

db2_profile::database::db_standby

When the named database does not yet run on the server, Puppet will use the backup at the `backup_path` to create an intial running database and set it in standby mode.

See the file "LICENSE" for the full license governing this code.

#### Parameters

The following parameters are available in the `db2_profile::database::db_standby` class:

* [`list`](#list)
* [`instance`](#instance)
* [`database`](#database)
* [`backup_path`](#backup_path)
* [`archive_path`](#archive_path)
* [`group`](#group)
* [`owner`](#owner)
* [`logoutput`](#logoutput)

##### <a name="list"></a>`list`

Data type: `Hash`

A hash of `db2_database` entries.

##### <a name="instance"></a>`instance`

Data type: `String[1]`

The instance to use for the database.

##### <a name="database"></a>`database`

Data type: `String[1]`

The database name to use for the primary or standby database.
this needs to be the same on the primary and standby nodes.

##### <a name="backup_path"></a>`backup_path`

Data type: `Stdlib::Absolutepath`

The path where DB2 can find the backup of this database.
Before applying this class, you'll have to use a `before_db_standby` class to copy the backup from the primary DB2 node to the location specified by this parameter.

##### <a name="archive_path"></a>`archive_path`

Data type: `String[1]`

The path to use for DB2 archiving.

##### <a name="group"></a>`group`

Data type: `String[1]`

The group to use for the archive and backup directories.

##### <a name="owner"></a>`owner`

Data type: `String[1]`

The owner to use for the archive and backup directories.

##### <a name="logoutput"></a>`logoutput`

Data type: `Variant[Boolean,Enum['on_failure']]`

If you want to see the output of the `exec` resources in the type, you can set this value to `true`.
The default is `on_failure`.
Here is an example on how to use this:
    class { '::db2_install::...':
      ...
      logoutput => true,
      ...
    }

Default value: `lookup({ name => 'logoutput', default_value => 'on_failure' })`

### <a name="db2_profiledatabasedb_startup"></a>`db2_profile::database::db_startup`

db2_profile::database::db_startup

See the file "LICENSE" for the full license governing this code.

#### Parameters

The following parameters are available in the `db2_profile::database::db_startup` class:

* [`instance_name`](#instance_name)
* [`location`](#location)

##### <a name="instance_name"></a>`instance_name`

Data type: `String[1]`



##### <a name="location"></a>`location`

Data type: `Stdlib::Absolutepath`

The locatin where the DB2 sofware is or will be installed.

### <a name="db2_profiledatabasedb_tablespaces"></a>`db2_profile::database::db_tablespaces`

db2_profile::database::db_tablespaces

Check the documentation of [db2_tablespace](/docs/db2_config/db2_tablespace) on how to do this and what properties you can define on an tablespace.

See the file "LICENSE" for the full license governing this code.

#### Parameters

The following parameters are available in the `db2_profile::database::db_tablespaces` class:

* [`list`](#list)

##### <a name="list"></a>`list`

Data type: `Hash`

The list of [db2_tablespace](/docs/db2_config/db2_tablespace.
html) tablespaces you want `db2_profile::database` to create and manage for you.

### <a name="db2_profiledatabasedb_users"></a>`db2_profile::database::db_users`

db2_profile::database::db_users

Check the documentation of [db2_user](/docs/db2_config/db2_user) on how to do this and what properties you can define on an user.

See the file "LICENSE" for the full license governing this code.

#### Parameters

The following parameters are available in the `db2_profile::database::db_users` class:

* [`list`](#list)

##### <a name="list"></a>`list`

Data type: `Hash`

The list of [db2_user](/docs/db2_config/db2_user.
html) users you want `db2_profile::database` to create and manage for you.

### <a name="db2_profiledatabaseem_license"></a>`db2_profile::database::em_license`

db2_profile::database::em_license

See the file "LICENSE" for the full license governing this code.

### <a name="db2_profiledatabasefact_caching"></a>`db2_profile::database::fact_caching`

db2_profile::database::fact_caching

See the file "LICENSE" for the full license governing this code.

#### Parameters

The following parameters are available in the `db2_profile::database::fact_caching` class:

* [`enabled`](#enabled)

##### <a name="enabled"></a>`enabled`

Data type: `Boolean`

Boolean to determine if you want to enabled Puppet fact caching for the DB2 facts.

### <a name="db2_profiledatabasepacemaker_setup"></a>`db2_profile::database::pacemaker_setup`

db2_profile::database::pacemaker_setup

Together these resources define a running Pacemaker cluster with multiple nodes.

See the file "LICENSE" for the full license governing this code.

#### Parameters

The following parameters are available in the `db2_profile::database::pacemaker_setup` class:

* [`clusters`](#clusters)
* [`databases`](#databases)
* [`instances`](#instances)
* [`qdevices`](#qdevices)
* [`vips`](#vips)

##### <a name="clusters"></a>`clusters`

Data type: `Hash`



##### <a name="databases"></a>`databases`

Data type: `Hash`

The Pacemaker database resources you want to ensure on the system.
See [here](/docs/db2_config/pcmkr_database.html) for the attributes of the [pcmk_database](/docs/db2_config/pcmkr_database.html)

##### <a name="instances"></a>`instances`

Data type: `Hash`

The Pacemaker instance resources you want to ensure on the system.
See [here](/docs/db2_config/pcmkr_instance.html) for the attributes of the [pcmk_instance](/docs/db2_config/pcmkr_instance.html)

##### <a name="qdevices"></a>`qdevices`

Data type: `Hash`

The Pacemaker qdevice resources you want to ensure on the system.
See [here](/docs/db2_config/pcmkr_qdevice.html) for the attributes of the [pcmk_qdevice](/docs/db2_config/pcmkr_qdevice.html)

##### <a name="vips"></a>`vips`

Data type: `Hash`

The Pacemaker vip resources you want to ensure on the system.
See [here](/docs/db2_config/pcmkr_vip.html) for the attributes of the [pcmk_vip](/docs/db2_config/pcmkr_vip.html)

### <a name="db2_profiledatabasepasswordless_root"></a>`db2_profile::database::passwordless_root`

db2_profile::database::passwordless_root

It will enable ssh access for the root account based on the specified private and public keys.

For this to work, **all** of the nodes must be reachable on the network before this class is applied.

See the file "LICENSE" for the full license governing this code.

#### Parameters

The following parameters are available in the `db2_profile::database::passwordless_root` class:

* [`nodes`](#nodes)
* [`private_key`](#private_key)
* [`public_key`](#public_key)

##### <a name="nodes"></a>`nodes`

Data type: `Array[String[1]]`

An array of nodes you want to enable passwordless root access between.

##### <a name="private_key"></a>`private_key`

Data type: `String[1]`



##### <a name="public_key"></a>`public_key`

Data type: `String[1]`

The public key to use to enable passwordless access between the nodes in the cluster.

### <a name="db2_profilesecured_database"></a>`db2_profile::secured_database`

db2_profile::secured_database

See the file "LICENSE" for the full license governing this code.

## Data types

### <a name="db2_profilesw_def"></a>`Db2_profile::Sw_def`

The Db2_profile::Sw_def data type.

Alias of

```puppet
Struct[{
    location  => Stdlib::Absolutepath,
    version   => String[1],
    file_name => String[1],
}]
```

