#
# db2_profile::database::db_users
#
# @summary This class contains the definition for all the database users you'd like on your system.
# When these customizations aren't enough, you can replace the class with your own class. See [db2_profile::database](./database.html) for an explanation on how to do this.
#
# @param [Hash] list
#    A list of database users to define.
#    You must specify a Hash of [db2_user](/docs/db2_config/db2_user.html)
#    The default value is: `{}`
#    This is a simple way to get started. It is easy to get started, but soon your hiera yaml become a nigtmare. Our advise is when you need to let puppet manage your DB2 schemas, to override this class and  add your own puppet implementation. This is much better maintainable
#    and adds more consistency.
#
#
# See the file "LICENSE" for the full license governing this code.
#
class db2_profile::database::db_schemas (
  Hash $list,
) {
  easy_type::debug_evaluation() # Show local variable on extended debug

  # This is a simple way to get started. It is easy to get started, but
  # soon your hiera yaml becomes a nigtmare. Our advise is when you need
  # to let Puppet manage your DB2 users, to override this class and 
  # add your own Puppet implementation. This is a much better, more
  # maintainable, and adds more consistency.
  #
  db2_config::databases_in($list).each |$database| {
    if ! db2_config::is_standby($database) {
      $list = db2_config::resources_for($list, $database)
      if $list.keys.size > 0 {
        echo { "Ensure DB schema(s) ${list.keys.join(',')}":
          withpath => false,
        }
      }
      ensure_resources(db2_schema, $list)
    } else {
      if $list.keys.size > 0 {
        echo { "Skipping DB2 schema(s) on ${database} because it is in standby mode": withpath => false }
      }
    }
  }
}
