#
# db2_profile::database::pacemaker_setup
#
# @summary This class takes care of applying all Pacemeker resources.
# Together these resources define a running Pacemaker cluster with multiple nodes.
#
# @param [Hash] clusters
#    
#
# @param [Hash] databases
#    The Pacemaker database resources you want to ensure on the system.
#    See [here](/docs/db2_config/pcmkr_database.html) for the attributes of the [pcmk_database](/docs/db2_config/pcmkr_database.html)
#
# @param [Hash] instances
#    The Pacemaker instance resources you want to ensure on the system.
#    See [here](/docs/db2_config/pcmkr_instance.html) for the attributes of the [pcmk_instance](/docs/db2_config/pcmkr_instance.html)
#
# @param [Hash] qdevices
#    The Pacemaker qdevice resources you want to ensure on the system.
#    See [here](/docs/db2_config/pcmkr_qdevice.html) for the attributes of the [pcmk_qdevice](/docs/db2_config/pcmkr_qdevice.html)
#
# @param [Hash] vips
#    The Pacemaker vip resources you want to ensure on the system.
#    See [here](/docs/db2_config/pcmkr_vip.html) for the attributes of the [pcmk_vip](/docs/db2_config/pcmkr_vip.html)
#
#
# See the file "LICENSE" for the full license governing this code.
#
class db2_profile::database::pacemaker_setup (
  Hash $clusters,
  Hash $databases,
  Hash $instances,
  Hash $qdevices,
  Hash $vips
) {
  easy_type::debug_evaluation() # Show local variable on extended debug

  if $clusters.keys.size > 0 {
    echo { "Ensure Pacemaker cluster ${clusters.keys.join(',')}":
      withpath => false,
    }
  }
  ensure_resources('pcmkr_cluster', $clusters)

  if $clusters.keys.size > 0 {
    echo { "Ensure Pacemaker instances ${instances.keys.join(',')}":
      withpath => false,
    }
  }
  ensure_resources('pcmkr_instance', $instances)

  if $databases.keys.size > 0 {
    echo { "Ensure Pacemaker databases ${databases.keys.join(',')}":
      withpath => false,
    }
  }
  ensure_resources('pcmkr_database', $databases)

  if $vips.keys.size > 0 {
    echo { "Ensure Pacemaker vips ${vips.keys.join(',')}":
      withpath => false,
    }
  }
  ensure_resources('pcmkr_vip', $vips)

  if $qdevices.keys.size > 0 {
    echo { "Ensure Pacemaker qdevices ${qdevices.keys.join(',')}":
      withpath => false,
    }
  }
  ensure_resources('pcmkr_qdevice', $qdevices)
}
